@@ -2,7 +2,6 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
    hspylib.main.hspylib.addons.appman
       @file: appman.py
@@ -22,6 +21,7 @@ from hspylib.addons.appman.app_type import AppType
 from hspylib.core.enums.http_code import HttpCode
 from hspylib.core.metaclass.singleton import Singleton
 from hspylib.core.tools.commons import get_path, syserr, sysout
+from hspylib.core.tools.preconditions import check_argument
 from hspylib.core.tools.text_tools import camelcase
 from hspylib.modules.cli.application.application import Application
 from hspylib.modules.cli.vt100.terminal import Terminal
@@ -57,7 +57,7 @@ project.ext.set("siteUrl", "YourSiteUrl")
         """Create the application based on the parameters"""
         sysout(f'Creating app: {app_name} -> {dest_dir} ...')
         try:
-            assert os.path.exists(dest_dir), f'Destination not found: {dest_dir}'
+            check_argument(os.path.exists(dest_dir), 'Destination not found: {}', dest_dir)
             self._app_name = app_name
             if app_type == AppType.APP:
                 self._app_dir = f'{dest_dir}/{app_name}'
@@ -108,11 +108,11 @@ project.ext.set("siteUrl", "YourSiteUrl")
         self._mkfile('src/main/resources/application.properties', '# Main application property file')
         self._mkdir('src/main/resources/log')
         self._mkfile('.env', '# Type in here the environment variables your app requires')
-        self._mkfile('run-it.sh', (self.TEMPLATES / "tpl-run-it.sh").read_text())
-        os.chmod(f'{self._app_dir}/run-it.sh', 0o755)
+        self._mkfile('run.sh', (self.TEMPLATES / "tpl-run.sh").read_text())
+        os.chmod(f'{self._app_dir}/run.sh', 0o755)
 
     def _apply_extensions(self, extensions: List[AppExtension], app_name: str):
-        """TODO"""
+        """Apply the selected extensions to the app"""
         if AppExtension.GRADLE in extensions:
             sysout('Applying gradle extensions')
             self._init_gradle(app_name)
@@ -168,7 +168,7 @@ project.ext.set("siteUrl", "YourSiteUrl")
     def _download_ext(self, extension: str) -> None:
         """Download a gradle extension from the HSPyLib repository"""
         resp = get(f'https://raw.githubusercontent.com/yorevs/hspylib/master/gradle/{extension}')
-        assert resp.status_code == HttpCode.OK, f'Unable to download {extension}'
+        check_argument(resp.status_code == HttpCode.OK, 'Unable to download {}', extension)
         self._mkfile(f'gradle/{extension}', resp.body)
 
     def _init_git(self) -> None:
