@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.core.crud.db.firebase
+   @Package: hspylib.main.hspylib.core.crud.db.firebase
       @file: firebase_config.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -25,6 +24,7 @@ from hspylib.core.config.app_config import AppConfigs
 from hspylib.core.enums.charset import Charset
 from hspylib.core.enums.http_code import HttpCode
 from hspylib.core.metaclass.singleton import Singleton
+from hspylib.core.tools.preconditions import check_argument, check_state
 from hspylib.modules.fetch.fetch import get
 
 
@@ -55,7 +55,7 @@ UUID={}
     @staticmethod
     def of_file(filename: str) -> 'FirebaseConfig':
         """TODO"""
-        assert os.path.exists(filename), "Config file does not exist"
+        check_argument(os.path.exists(filename), "Config file does not exist")
 
         with open(filename) as f_config:
             cfg = CaseInsensitiveDict()
@@ -65,17 +65,19 @@ UUID={}
                     continue
                 key, value = line.split("=", 1)
                 cfg[key.strip()] = value.strip()
-            assert len(cfg) > 4, \
-                "Invalid configuration file. Must include at least: [PROJECT_ID, FIREBASE_URL, USERNAME, PASSPHRASE]"
+            check_state(
+                len(cfg) > 4,
+                "Invalid configuration file. Must include at least: [PROJECT_ID, FIREBASE_URL, USERNAME, PASSPHRASE]")
 
             return FirebaseConfig.of(cfg) if len(cfg) == 5 else None
 
-    def __init__(self,
-                 project_id: str = None,
-                 database: str = None,
-                 project_uuid: str = None,
-                 username: str = None,
-                 passphrase: str = None):
+    def __init__(
+        self,
+        project_id: str = None,
+        database: str = None,
+        project_uuid: str = None,
+        username: str = None,
+        passphrase: str = None):
 
         self.encoding = str(Charset.UTF_8).lower()
         self.current_state = None
@@ -84,13 +86,13 @@ UUID={}
         self.project_uuid = project_uuid if project_uuid else AppConfigs.INSTANCE['firebase.project.uuid']
         self.username = username if username else AppConfigs.INSTANCE['firebase.username']
         self.passphrase = passphrase if passphrase else AppConfigs.INSTANCE['firebase.passphrase']
-        assert self.project_id, "Project ID must be defined"
-        assert self.database, "Database name must be defined"
-        assert self.username, "Username must be defined"
+        check_state(self.project_id, "Project ID must be defined")
+        check_state(self.database, "Database name must be defined")
+        check_state(self.username, "Username must be defined")
         self.set_passphrase()
         self.project_uuid = str(self.project_uuid) if self.project_uuid else str(uuid.uuid4())
-        assert self.validate_config(), "Your Firebase configuration is not valid"
-        log.debug(f'Successfully connected to Firebase: {self.base_url()}')
+        check_state(self.validate_config(), "Your Firebase configuration is not valid")
+        log.debug("Successfully connected to Firebase: %s", self.base_url())
 
     def __str__(self):
         return self.CONFIG_FORMAT.format(
@@ -103,8 +105,9 @@ UUID={}
 
     def set_passphrase(self) -> None:
         """TODO"""
-        assert self.passphrase and len(self.passphrase) >= 8, \
-            "Passphrase must be have least 8 characters size and must be base64 encoded"
+        check_state(
+            self.passphrase and len(self.passphrase) >= 8,
+            "Passphrase must be have least 8 characters size and must be base64 encoded")
         self.passphrase = str(base64.b64decode(self.passphrase), encoding=self.encoding)
 
     def validate_config(self) -> bool:
