@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.core.tools
+   @package: hspylib.main.hspylib.core.tools
       @file: commons.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -20,7 +19,7 @@ import pathlib
 import re
 import sys
 from datetime import timedelta, datetime
-from typing import Any, List, Optional, Tuple, Type
+from typing import Any, List, Optional, Tuple, Type, Union
 
 from hspylib.core.tools.constants import DATE_TIME_FORMAT
 from hspylib.core.tools.validator import Validator
@@ -47,11 +46,11 @@ def _reset_logger():
 
 
 def log_init(
-        log_file: str,
-        create_new: bool = True,
-        mode: str = 'a',
-        level: int = log.DEBUG,
-        filename: str = LOG_FMT) -> log:
+    log_file: str,
+    create_new: bool = True,
+    mode: str = 'a',
+    level: int = log.DEBUG,
+    filename: str = LOG_FMT) -> bool:
     """Initialize the system logger
     :param log_file: TODO
     :param create_new:  TODO
@@ -70,7 +69,8 @@ def log_init(
             format=filename,
             level=level,
             filemode=mode)
-        log.info(f"Logging started. filename={os.path.basename(log_file)} level={level} mode={mode} append={not create}")
+        log.info(
+            "Logger init. filename=%s level=%s mode=%s append=%s", os.path.basename(log_file), level, mode, not create)
 
     return os.path.exists(log_file)
 
@@ -86,6 +86,7 @@ def now() -> str:
     """TODO"""
     return datetime.now().strftime(DATE_TIME_FORMAT)
 
+
 def now_ms() -> int:
     return int(datetime.now().timestamp())
 
@@ -93,7 +94,7 @@ def now_ms() -> int:
 def read_version(version_filepath: str = ".version") -> Tuple:
     """Retrieve the version from the version file in the form: Tuple[major,minor,build]"""
     try:
-        log.info(f"Reading version from {version_filepath}")
+        log.info("Reading version from %s", version_filepath)
         with open(version_filepath) as fh_version:
             ver = tuple(map(str.strip, fh_version.read().split('.')))
             return ver if ver else (0, 0, 0)
@@ -190,7 +191,35 @@ def flatten_dict(dictionary: dict, parent_key='', sep='.') -> dict:
     return flat_dict
 
 
-def get_or_default(options: tuple, index: int, default_value=None) -> Optional[Any]:
+def search_dict(root_element: dict, search_path: str, parent_key='', sep='.') -> Optional[Any]:
+    """
+    TODO
+    :param root_element:
+    :param search_path:
+    :param parent_key:
+    :param sep:
+    :return:
+    """
+    found = search_path == parent_key
+    el = None
+    if not found and isinstance(root_element, dict):
+        for key, value in root_element.items():
+            if found:
+                break
+            el_path = parent_key + sep + key if parent_key else key
+            if search_path == el_path:
+                found, el = True, value
+                break
+            if isinstance(value, dict):
+                found, el = search_dict(value, search_path, el_path, sep=sep)
+            elif isinstance(value, list):
+                for next_val in value:
+                    found, el = search_dict(next_val, search_path, el_path, sep=sep)
+            # Skip if the element is a leaf
+
+    return found, el
+
+def get_or_default(options: Union[tuple, list], index: int, default_value=None) -> Optional[Any]:
     """Retrieve an item from the options list or default_value if index is out of range
     :param options: The available list of options
     :param index: The index of the item
@@ -291,3 +320,13 @@ def human_readable_time(time_microseconds: int) -> str:
     str_line = f"{hours:02d}:{minutes:02d}:{seconds:02d}.{microseconds:06d}"
 
     return str_line
+
+
+def build_url(url_or_part: str) -> str:
+    """TODO
+    :param url_or_part:
+    """
+    if re.match(r'https?://.*', url_or_part):
+        return url_or_part
+
+    return f"http://{url_or_part}"
