@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.modules.cli.vt100
+   @package: hspylib.main.hspylib.modules.cli.vt100
       @file: vt_utils.py
    @created: Tue, 4 May 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -29,7 +28,8 @@ from hspylib.modules.cli.vt100.vt_colors import VtColors
 
 
 def require_terminal():
-    assert sys.stdin.isatty(), 'This module requires a terminal (TTY)'
+    if not sys.stdin.isatty():
+        raise Exception('This module requires a terminal (TTY)')
 
 
 def screen_size() -> Optional[List[str]]:
