@@ -2,9 +2,8 @@
 # -*- coding: utf-8 -*-
 
 """
-   TODO Purpose of the file
    @project: HSPyLib
-   hspylib.main.hspylib.modules.eventbus
+   @package: hspylib.main.hspylib.modules.eventbus
       @file: event.py
    @created: Wed, 30 Jun 2021
     @author: <B>H</B>ugo <B>S</B>aporetti <B>J</B>unior"
@@ -14,6 +13,7 @@
    Copyright 2021, HSPyLib team
 """
 
+
 class Event:
     """TODO"""
 
